FlutterProjectCleaner class

Inheritance

Constructors

FlutterProjectCleaner({required String root, required FileSystemService fileSystem})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
no setteroverride
root → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

discover() → Future<List<CleanupTarget>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited