SystemCleaner class

Inheritance

Constructors

SystemCleaner({required PlatformService platform, required AppConfig config})
const

Properties

config → AppConfig
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
no setteroverride
platform → PlatformService
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

discover() → Future<List<CleanupTarget>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited