CommandContext class

Constructors

CommandContext({required Logger logger, PlatformService? platform, FileSystemService? fileSystem, ProcessService? process, ConfigService? config, TerminalService? terminal})

Properties

config → ConfigService
final
fileSystem → FileSystemService
final
hashCode → int
The hash code for this object.
no setterinherited
logger → Logger
final
platform → PlatformService
final
process → ProcessService
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
terminal → TerminalService
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited