CleanConfig class

Constructors

CleanConfig({bool gradle = true, bool xcode = true, bool cocoapods = true, bool trash = false})
const

Properties

cocoapods → bool
final
gradle → bool
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trash → bool
final
xcode → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited