CleanupResult class

Constructors

CleanupResult({required CleanupTarget target, required int bytesReclaimed, required bool deleted, String? skippedReason})
const

Properties

bytesReclaimed → int
final
deleted → bool
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skippedReason → String?
final
target → CleanupTarget
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited