CleanupTarget class

Constructors

CleanupTarget({required String id, required String label, required String path, required CleanupCategory category, bool destructive = true, bool contentsOnly = false, List<String>? command})
const

Properties

category CleanupCategory
final
command List<String>?
final
contentsOnly bool
final
destructive bool
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
label String
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited