ScanResult class

Constructors

ScanResult({required List<ScanEntry> entries, required List<String> scannedRoots})
const

Properties

entries → List<ScanEntry>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scannedRoots → List<String>
final
totalBytes → int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited