CleaningService class
Constructors
-
CleaningService({required List<
Cleaner> cleaners, required TargetCleaner targetCleaner}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cleanTargets(
List< CleanupTarget> targets, {required bool dryRun}) → Future<CleanupSummary> -
discoverTargets(
) → Future< List< CleanupTarget> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited