FileSystemService class

Constructors

FileSystemService()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String path, {required bool dryRun}) Future<bool>
deleteChildren(String path, {required bool dryRun}) Future<bool>
exists(String path) bool
findNamedDirectories({required String root, required Set<String> names, int maxDepth = 6, Set<String> protectedNames = const {'.git', '.idea', '.vscode', 'node_modules', 'Library', 'Applications', 'System', 'Volumes', 'private'}}) Future<List<String>>
findNamedFiles({required String root, required Set<String> names, int maxDepth = 6, Set<String> protectedNames = const {'.git', '.idea', '.vscode', 'node_modules', 'Library', 'Applications', 'System', 'Volumes'}}) Future<List<String>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sizeOf(String path) Future<int>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited