Logger class

Constructors

Logger({Level level = Level.info})

Properties

hashCode int
The hash code for this object.
no setterinherited
level Level
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

chooseOne(String message, {required List<String> choices, String? defaultValue}) String
confirm(String message, {bool defaultValue = false}) bool
detail(String message) → void
err(String message) → void
info(String message) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prompt(String message, {String defaultValue = ''}) String
success(String message) → void
toString() String
A string representation of this object.
inherited
warn(String message, {String? tag}) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited