ConfigService class

Constructors

ConfigService()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

exists({String directory = '.'}) Future<bool>
load({String directory = '.'}) Future<AppConfig>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
writeDefault({String directory = '.', bool overwrite = false}) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fileName → const String