PlatformService class
Constructors
-
PlatformService({HostPlatform? current, Map<
String, String> ? environment}) -
const
Properties
- androidBuildCache → String?
-
no setter
- androidGradleCache → String?
-
no setter
- cocoaPodsCache → String?
-
no setter
- current → HostPlatform
-
no setter
-
environment
→ Map<
String, String> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- homeDirectory → String?
-
no setter
- isLinux → bool
-
no setter
- isMacOS → bool
-
no setter
- isWindows → bool
-
no setter
- pubCacheDirectory → String?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tempDirectory → String
-
no setter
- trashDirectory → String?
-
no setter
- xcodeDerivedData → String?
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited