ScannerService class

Constructors

ScannerService({required FileSystemService fileSystem, required PlatformService platform})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cacheEntries() Future<List<ScanEntry>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scan({required List<String> roots, int maxDepth = 6}) Future<ScanResult>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited