TerminalService class
Constructors
- TerminalService({required Logger logger})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isInteractive → bool
-
no setter
- logger → Logger
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
chooseOne(
String message, {required List< String> choices, String? defaultValue}) → String -
confirm(
String message, {bool defaultValue = false, bool assumeYes = false}) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
prompt(
String message, {String defaultValue = ''}) → String -
toString(
) → String -
A string representation of this object.
inherited
-
withSpinner<
T> (String message, Future< T> action()) → Future<T>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited